supp NIH: structure is is "shows/nature" to check: https://dsld.od.nih.gov/label/222961 https://dsld.od.nih.gov/label/220884 https://dsld.od.nih.gov/label/277843 chia seeds! https://dsld.od.nih.gov/label/214893 off market, https://dsld.od.nih.gov/label/79829 rice, hemp, chia: https://dsld.od.nih.gov/label/69439 pea protein? https://dsld.od.nih.gov/label/77096 https://dsld.od.nih.gov/label/75972 https://dsld.od.nih.gov/label/75692 images: https://s3-us-gov-west-1.amazonaws.com/cg-355fa78b-864d-4a44-b287-0369f11f024a